==> dateparser_1.0.0.orig.tar.gz: dateparser-1.0.0/dateparser/data/date_translation_data/zu.py <==
info = {
    "name": "zu",
    "date_order": "MDY",
    "january": [
        "januwari",
        "jan",
        "umasingana"
    ],
    "february": [
        "februwari",
        "feb"
    ],
    "march": [
        "mashi",
        "mas"
    ],
    "april": [
        "ephreli",
        "eph"
    ],
    "may": [
        "meyi",
        "mey"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "julayi",
        "jul"
    ],
    "august": [
        "agasti",
        "aga"
    ],
    "september": [
        "septhemba",
        "sep"
    ],
    "october": [
        "okthoba",
        "okt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "disemba",
        "dis"
    ],
    "monday": [
        "umsombuluko",
        "mso"
    ],
    "tuesday": [
        "ulwesibili",
        "bil"
    ],
    "wednesday": [
        "ulwesithathu",
        "tha"
    ],
    "thursday": [
        "ulwesine",
        "sin"
    ],
    "friday": [
        "ulwesihlanu",
        "hla"
    ],
    "saturday": [
        "umgqibelo",
        "mgq"
    ],
    "sunday": [
        "isonto",
        "son"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "unyaka"
    ],
    "month": [
        "inyanga"
    ],
    "week": [
        "iviki"
    ],
    "day": [
        "usuku"
    ],
    "hour": [
        "ihora"
    ],
    "minute": [
        "iminithi"
    ],
    "second": [
        "isekhondi"
    ],
    "relative-type": {
        "1 year ago": [
            "onyakeni odlule"
        ],
        "0 year ago": [
            "kulo nyaka"
        ],
        "in 1 year": [
            "unyaka ozayo"
        ],
        "1 month ago": [
            "inyanga edlule"
        ],
        "0 month ago": [
            "le nyanga"
        ],
        "in 1 month": [
            "inyanga ezayo"
        ],
        "1 week ago": [
            "iviki eledlule"
        ],
        "0 week ago": [
            "leli viki"
        ],
        "in 1 week": [
            "iviki elizayo"
        ],
        "1 day ago": [
            "izolo"
        ],
        "0 day ago": [
            "namhlanje"
        ],
        "in 1 day": [
            "kusasa"
        ],
        "0 hour ago": [
            "leli hora"
        ],
        "0 minute ago": [
            "leli minithi"
        ],
        "0 second ago": [
            "manje"
        ]
    },
    "relative-type-regex": {
        "\\1 year ago": [
            "(\\d+) unyaka odlule",
            "(\\d+) iminyaka edlule"
        ],
        "\\1 month ago": [
            "(\\d+) inyanga edlule",
            "(\\d+) izinyanga ezedlule"
        ],
        "\\1 day ago": [
            "(\\d+) usuku olwedlule",
            "(\\d+) izinsuku ezedlule"
        ],
        "\\1 hour ago": [
            "(\\d+) ihora eledlule",
            "(\\d+) amahora edlule"
        ],
        "\\1 minute ago": [
            "(\\d+) iminithi eledlule",
            "(\\d+) amaminithi edlule"
        ],
        "\\1 second ago": [
            "(\\d+) isekhondi eledlule",
            "(\\d+) amasekhondi edlule"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser_1.1.0.orig.tar.gz: dateparser-1.1.0/dateparser/data/date_translation_data/zu.py <==
info = {
    "name": "zu",
    "date_order": "MDY",
    "january": [
        "jan",
        "januwari",
        "umasingana"
    ],
    "february": [
        "feb",
        "februwari"
    ],
    "march": [
        "mas",
        "mashi"
    ],
    "april": [
        "eph",
        "ephreli"
    ],
    "may": [
        "mey",
        "meyi"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "julayi"
    ],
    "august": [
        "aga",
        "agasti"
    ],
    "september": [
        "sep",
        "septhemba"
    ],
    "october": [
        "okt",
        "okthoba"
    ],
    "november": [
        "nov",
        "novemba"
    ],
    "december": [
        "dis",
        "disemba"
    ],
    "monday": [
        "mso",
        "umsombuluko"
    ],
    "tuesday": [
        "bil",
        "ulwesibili"
    ],
    "wednesday": [
        "tha",
        "ulwesithathu"
    ],
    "thursday": [
        "sin",
        "ulwesine"
    ],
    "friday": [
        "hla",
        "ulwesihlanu"
    ],
    "saturday": [
        "mgq",
        "umgqibelo"
    ],
    "sunday": [
        "isonto",
        "son"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "unyaka"
    ],
    "month": [
        "inyanga"
    ],
    "week": [
        "iviki"
    ],
    "day": [
        "usuku"
    ],
    "hour": [
        "ihora"
    ],
    "minute": [
        "iminithi"
    ],
    "second": [
        "isekhondi"
    ],
    "relative-type": {
        "0 day ago": [
            "namhlanje"
        ],
        "0 hour ago": [
            "leli hora"
        ],
        "0 minute ago": [
            "leli minithi"
        ],
        "0 month ago": [
            "le nyanga"
        ],
        "0 second ago": [
            "manje"
        ],
        "0 week ago": [
            "leli viki"
        ],
        "0 year ago": [
            "kulo nyaka"
        ],
        "1 day ago": [
            "izolo"
        ],
        "1 month ago": [
            "inyanga edlule"
        ],
        "1 week ago": [
            "iviki eledlule"
        ],
        "1 year ago": [
            "onyakeni odlule"
        ],
        "in 1 day": [
            "kusasa"
        ],
        "in 1 month": [
            "inyanga ezayo"
        ],
        "in 1 week": [
            "iviki elizayo"
        ],
        "in 1 year": [
            "unyaka ozayo"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) izinsuku ezedlule",
            "(\\d+) usuku olwedlule"
        ],
        "\\1 hour ago": [
            "(\\d+) amahora edlule",
            "(\\d+) ihora eledlule"
        ],
        "\\1 minute ago": [
            "(\\d+) amaminithi edlule",
            "(\\d+) iminithi eledlule"
        ],
        "\\1 month ago": [
            "(\\d+) inyanga edlule",
            "(\\d+) izinyanga ezedlule"
        ],
        "\\1 second ago": [
            "(\\d+) amasekhondi edlule",
            "(\\d+) isekhondi eledlule"
        ],
        "\\1 year ago": [
            "(\\d+) iminyaka edlule",
            "(\\d+) unyaka odlule"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
